maxEntrySizeBytes property
Maximum byte size allowed for a single cached response. Responses exceeding this limit will not be cached.
Implementation
int maxEntrySizeBytes;
Maximum byte size allowed for a single cached response. Responses exceeding this limit will not be cached.
int maxEntrySizeBytes;