onCacheHit property
Optional callback triggered when a request hits the cache, passing the request URL and current cache stats.
Implementation
final void Function(String url, CacheStats stats)? onCacheHit;
Optional callback triggered when a request hits the cache, passing the request URL and current cache stats.
final void Function(String url, CacheStats stats)? onCacheHit;