FirestoreApiProviderImpl class

Implemented types

Constructors

FirestoreApiProviderImpl({CachingHttpClient? cachingClient})

Properties

api ↔ FirestoreApi
getter/setter pairoverride-getter
cachingClient CachingHttpClient?
Optional caching HTTP client wrapper. If null, requests will not be cached.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() Future<void>
override
init() Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited