PathUtils class

Various path utils

Constructors

PathUtils()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

join(String? path1, String? path2) → String
Join paths
name(String? resourcePath) → String
Get resource name from full path
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parent(String? resourcePath) → String
Returns the parent path of resourcePath.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited