ValueMapper class
Mapper from firestore value to json and vice versa.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
fromJsonObject(
dynamic json) → Value -
Converts a JSON object to its corresponding Firestore
Valuerepresentation. -
init(
{String? locationPrefix, String? referencePrefix, String? bytesPrefix, String? datetimePrefix}) → void - Initializes the prefixes used for encoding specific data types.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJsonObject(
Value value) → dynamic -
Converts a Firestore
Valueto its corresponding JSON representation. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- kBytesPrefix → const String
- kDatetimePrefix → const String
- kLocationPrefix → const String
- kReferencePrefix → const String